package io.renren.modules.admin.controller;

import java.util.Arrays;
import java.util.Date;
import java.util.Map;

import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import io.renren.modules.admin.entity.MemberEntity;
import io.renren.modules.admin.service.MemberService;
import io.renren.common.utils.PageUtils;
import io.renren.common.utils.R;
import io.renren.common.validator.ValidatorUtils;
import io.renren.common.validator.group.AddGroup;
import io.renren.common.validator.group.UpdateGroup;
import io.renren.common.utils.MyUtils;


/**
 * 
 *
 * @author huwhois
 * @email huwhois@163.com
 * @date 2020-12-09 14:33:56
 */
@RestController
@RequestMapping("admin/member")
public class MemberController {
    @Autowired
    private MemberService memberService;

    /**
     * 列表
     */
    @GetMapping("/list")
    @RequiresPermissions("admin:member:list")
    public R list(@RequestParam Map<String, Object> params){
        PageUtils page = memberService.queryPage(params);

        return R.ok().put("page", page);
    }

    /**
     * 信息
     */
    @GetMapping("/info/{id}")
    @RequiresPermissions("admin:member:info")
    public R info(@PathVariable("id") Long id){
		MemberEntity member = memberService.getById(id);

        return R.ok().put("member", member);
    }

    /**
     * 保存
     */
    @PostMapping("/save")
    @RequiresPermissions("admin:member:save")
    public R save(@RequestBody MemberEntity member){
        ValidatorUtils.validateEntity(member, AddGroup.class);
        memberService.saveMember(member);

        return R.ok();
    }

    /**
     * 修改
     */
    @PostMapping("/update")
    @RequiresPermissions("admin:member:update")
    public R update(@RequestBody MemberEntity member){
        ValidatorUtils.validateEntity(member, UpdateGroup.class);
		memberService.updateMember(member);

        return R.ok();
    }

    /**
     * 删除
     */
    @PostMapping("/delete")
    @RequiresPermissions("admin:member:delete")
    public R delete(@RequestBody Long[] ids){
		memberService.removeByIds(Arrays.asList(ids));

        return R.ok();
    }

    /**
     * 改变备注
     * @param params
     * @return
     */
    @PostMapping("/remark")
    @RequiresPermissions("admin:member:update")
    public R remark(@RequestBody Map<String, Object> params){   
        Long id = Long.valueOf(params.get("id").toString());
        String remark =params.get("remark").toString();
        int res = memberService.updateRemark(id, remark);
        if (res == 0) {
            return R.error();
        }
        return R.ok();
    }

    /**
     * 修改flag
     * @param params
     * @return
     */
    @PostMapping("/flag")
    @RequiresPermissions("admin:member:update")
    public R flag(@RequestBody Map<String, Object> params){   
        Long id = Long.valueOf(params.get("id").toString());
        Long flag = Long.valueOf(params.get("flag").toString());
        int res = memberService.updateFlag(id, flag);
        if (res == 0) {
            return R.error("用户不存在");
        }
        return R.ok();
    }

}
